'use strict';

var _chai = require('chai');

var _url = require('../utils/url');

describe('mapUrl', function () {
  it('extracts nothing if both params are undefined', function () {
    (0, _chai.expect)((0, _url.mapUrl)(undefined, undefined)).to.deep.equal({
      action: null,
      params: []
    });
  });

  it('extracts nothing if the url is empty', function () {
    var url = '';
    var splittedUrlPath = url.split('?')[0].split('/').slice(1);
    var availableActions = { a: 1, widget: { c: 1, load: function load() {
          return 'baz';
        } } };

    (0, _chai.expect)((0, _url.mapUrl)(availableActions, splittedUrlPath)).to.deep.equal({
      action: null,
      params: []
    });
  });

  it('extracts nothing if nothing was found', function () {
    var url = '/widget/load/?foo=bar';
    var splittedUrlPath = url.split('?')[0].split('/').slice(1);
    var availableActions = { a: 1, info: { c: 1, load: function load() {
          return 'baz';
        } } };

    (0, _chai.expect)((0, _url.mapUrl)(availableActions, splittedUrlPath)).to.deep.equal({
      action: null,
      params: []
    });
  });

  it('extracts the available actions and the params from an relative url string with GET params', function () {
    var url = '/widget/load/param1/xzy?foo=bar';
    var splittedUrlPath = url.split('?')[0].split('/').slice(1);
    var availableActions = { a: 1, widget: { c: 1, load: function load() {
          return 'baz';
        } } };

    (0, _chai.expect)((0, _url.mapUrl)(availableActions, splittedUrlPath)).to.deep.equal({
      action: availableActions.widget.load,
      params: ['param1', 'xzy']
    });
  });

  it('extracts the available actions from an url string without GET params', function () {
    var url = '/widget/load/?foo=bar';
    var splittedUrlPath = url.split('?')[0].split('/').slice(1);
    var availableActions = { a: 1, widget: { c: 1, load: function load() {
          return 'baz';
        } } };

    (0, _chai.expect)((0, _url.mapUrl)(availableActions, splittedUrlPath)).to.deep.equal({
      action: availableActions.widget.load,
      params: ['']
    });
  });

  it('does not find the avaialble action if deeper nesting is required', function () {
    var url = '/widget';
    var splittedUrlPath = url.split('?')[0].split('/').slice(1);
    var availableActions = { a: 1, widget: { c: 1, load: function load() {
          return 'baz';
        } } };

    (0, _chai.expect)((0, _url.mapUrl)(availableActions, splittedUrlPath)).to.deep.equal({
      action: null,
      params: []
    });
  });
});