'use strict';

var _chai = require('chai');

var _load = require('../widget/load');

var _load2 = _interopRequireDefault(_load);

var _sinon = require('sinon');

var _sinon2 = _interopRequireDefault(_sinon);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('widget load', function () {

  afterEach(function () {
    if ('restore' in Math.random) {
      Math.random.restore(); // reset the Math.random fixture
    }
  });

  describe('successful', function () {

    beforeEach(function () {
      _sinon2.default.stub(Math, 'random').returns(0.4);
    });

    it('uses the widgets from the session', function () {
      return (0, _load2.default)({ session: { widgets: ['a', 'b', 'c'] } }).then(function (widgets) {
        (0, _chai.expect)(widgets.length).to.equal(3);
      });
    });

    it('initializes the widgets ', function () {
      return (0, _load2.default)({ session: {} }).then(function (widgets) {
        (0, _chai.expect)(widgets.length).to.equal(4);
        (0, _chai.expect)(widgets[0].color).to.equal('Red');
      });
    });
  });

  describe('unsuccessful', function () {

    beforeEach(function () {
      _sinon2.default.stub(Math, 'random').returns(0.2);
    });

    it('rejects the call', function () {
      return (0, _load2.default)({ session: {} }).then(function () {}, function (err) {
        (0, _chai.expect)(err).to.equal('Widget load fails 33% of the time. You were unlucky.');
      });
    });
  });
});