'use strict';

var _chai = require('chai');

var _update = require('../widget/update');

var _update2 = _interopRequireDefault(_update);

var _sinon = require('sinon');

var _sinon2 = _interopRequireDefault(_sinon);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('widget update', function () {

  afterEach(function () {
    if ('restore' in Math.random) {
      Math.random.restore(); // reset the Math.random fixture
    }
  });

  describe('randomly successful', function () {

    beforeEach(function () {
      _sinon2.default.stub(Math, 'random').returns(0.3);
    });

    it('does not accept green widgets', function () {
      return (0, _update2.default)({ session: {}, body: { color: 'Green' } }).then(function () {}, function (err) {
        (0, _chai.expect)(err.color).to.equal('We do not accept green widgets');
      });
    });

    it('updates a widget', function () {
      var widget = { id: 2, color: 'Blue' };
      return (0, _update2.default)({ session: {}, body: widget }).then(function (res) {
        (0, _chai.expect)(res).to.deep.equal(widget);
      });
    });
  });

  describe('randomly unsuccessful', function () {

    beforeEach(function () {
      _sinon2.default.stub(Math, 'random').returns(0.1);
    });

    it('rejects the call in 20% of the time', function () {
      return (0, _update2.default)().then(function () {}, function (err) {
        (0, _chai.expect)(err).to.equal('Oh no! Widget save fails 20% of the time. Try again.');
      });
    });
  });
});