'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

exports.default = createNewGroup;

var _system = require('../../utils/system');

var _system2 = _interopRequireDefault(_system);

var _loggingManager = require('logging-manager');

var _devDelay = require('../../utils/devDelay.js');

var _devDelay2 = _interopRequireDefault(_devDelay);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function createNewGroup(req) {
  return new _promise2.default(function (resolve, reject) {
    return (0, _devDelay2.default)(2000).then(function () {
      var newGroupName = req.body.newGroupName;

      if (!newGroupName) {
        _loggingManager.Instance.debug('System', 'createNewGroup', 'Blank group name passed.');
        reject({
          status: 400,
          errorField: 'newGroupName',
          errorReason: 'No group name was passed to create request.'
        });
      } else if (newGroupName.length > 15) {
        _loggingManager.Instance.debug('System', 'createNewGroup', 'Invalid group name passed: ' + newGroupName);
        reject({
          status: 400,
          errorField: 'newGroupName',
          errorReason: 'The group name is invalid. It must be 15 characters or less.'
        });
      } else {
        _loggingManager.Instance.debug('System', 'createNewGroup', 'Creating group using name: ' + newGroupName);
        _system2.default.createGroup(newGroupName).then(function (newGroupId) {
          resolve({
            newGroupId: newGroupId
          });
        }, function (error) {
          _loggingManager.Instance.error('System', 'createNewGroup', 'Error occured creating group using name: ' + newGroupName);
          _loggingManager.Instance.error('System', 'createNewGroup', error);
          reject({
            status: 500,
            errorField: 'newGroupName',
            errorReason: 'An error occured while trying to create group. Please check the config file as it may be out of sync and the application may require a restart.'
          });
        });
      }
    });
  });
}
module.exports = exports['default'];