'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

exports.default = createNewLog;

var _system = require('../../utils/system');

var _system2 = _interopRequireDefault(_system);

var _loggingManager = require('logging-manager');

var _devDelay = require('../../utils/devDelay.js');

var _devDelay2 = _interopRequireDefault(_devDelay);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function createNewLog(req) {
  return new _promise2.default(function (resolve, reject) {
    return (0, _devDelay2.default)(2000).then(function () {
      var _req$body = req.body;
      var logName = _req$body.logName;
      var groupId = _req$body.groupId;
      var logFile = _req$body.logFile;
      var logPath = _req$body.logPath;

      if (!logName) {
        _loggingManager.Instance.debug('System', 'createNewLog', 'Blank log name passed.');
        reject({
          status: 400,
          errorField: 'newLogName',
          errorReason: 'No log name was passed to create log request.'
        });
      } else if (logName.length > 15) {
        _loggingManager.Instance.debug('System', 'createNewLog', 'Invalid log name passed: ' + logName);
        reject({
          status: 400,
          errorField: 'newLogName',
          errorReason: 'The log name "' + logName + '" is invalid. It must be 15 characters or less.'
        });
      } else if (groupId === '-1') {
        _loggingManager.Instance.debug('System', 'createNewLog', 'Default group ID passed.');
        reject({
          status: 400,
          errorField: 'newLogFile',
          errorReason: 'No group was passed to create log request.'
        });
      } else if (!_system2.default.groupIdIsValid(groupId)) {
        _loggingManager.Instance.debug('System', 'createNewLog', 'Invalid group ID passed.');
        reject({
          status: 400,
          errorField: 'newGroupId',
          errorReason: 'Invalid group ID was passed to create request. No group exists for that ID.'
        });
      } else if (!logFile) {
        _loggingManager.Instance.debug('System', 'createNewLog', 'Blank log file name passed.');
        reject({
          status: 400,
          errorField: 'newLogFile',
          errorReason: 'No log file name was passed to create log request.'
        });
      } else if (logFile.length > 1000) {
        _loggingManager.Instance.debug('System', 'createNewLog', 'Invalid log file passed: ' + logFile);
        reject({
          status: 400,
          errorField: 'newLogFile',
          errorReason: 'The log file name "' + logFile + '" is invalid. It must be 1000 characters or less.'
        });
      } else if (!logPath) {
        _loggingManager.Instance.debug('System', 'createNewLog', 'Blank log path passed.');
        reject({
          status: 400,
          errorField: 'newLogPath',
          errorReason: 'No log file path was passed to create log request.'
        });
      } else if (logPath.length > 1000) {
        _loggingManager.Instance.debug('System', 'createNewLog', 'Invalid log file path passed: ' + logPath);
        reject({
          status: 400,
          errorField: 'newLogPath',
          errorReason: 'The log file path "' + logPath + '" is invalid. It must be 1000 characters or less.'
        });
      } else {
        _loggingManager.Instance.debug('System', 'createNewLog', 'Creating group using: ' + logName + ' ' + groupId + ' ' + logFile + ' ' + logPath);
        _system2.default.createLog(logName, groupId, logFile, logPath).then(function (newLogId) {
          resolve({
            newLogId: newLogId
          });
        }, function (error) {
          _loggingManager.Instance.error('System', 'createNewLog', 'Error occured creating group using name: ' + logName);
          _loggingManager.Instance.error('System', 'createNewLog', error);
          reject({
            status: 500,
            errorField: 'newLogName',
            errorReason: 'An error occured while trying to create group. Please check the config file as it may be out of sync and the application may require a restart.'
          });
        });
      }
    });
  });
}
module.exports = exports['default'];