'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

exports.default = deleteGroup;

var _system = require('../../utils/system');

var _system2 = _interopRequireDefault(_system);

var _loggingManager = require('logging-manager');

var _devDelay = require('../../utils/devDelay.js');

var _devDelay2 = _interopRequireDefault(_devDelay);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function deleteGroup(req) {
  return new _promise2.default(function (resolve, reject) {
    return (0, _devDelay2.default)(2000).then(function () {
      var groupId = req.body.groupId;

      if (!groupId) {
        _loggingManager.Instance.debug('System', 'deleteGroup', 'Blank group ID passed.');
        reject({
          status: 400,
          errorField: 'groupId',
          errorReason: 'No group ID was passed to delete request.'
        });
      } else if (!_system2.default.groupIdIsValid(groupId)) {
        _loggingManager.Instance.debug('System', 'deleteGroup', 'Invalid group ID passed: ' + groupId);
        reject({
          status: 400,
          errorField: 'groupId',
          errorReason: 'The group ID "' + groupId + '" is invalid. No group exists for that ID.'
        });
      } else {
        _loggingManager.Instance.debug('System', 'deleteGroup', 'Deleting group using groupId: ' + groupId);
        _system2.default.deleteGroup(groupId).then(function () {
          resolve();
        }, function (error) {
          _loggingManager.Instance.error('System', 'deleteGroup', 'Error occured deleting group using groupId: ' + groupId);
          _loggingManager.Instance.error('System', 'deleteGroup', error);
          reject({
            status: 500,
            errorField: 'groupName',
            errorReason: 'An error occured while trying to delete group. Please check the config file as it may be out of sync and the application may require a restart.'
          });
        });
      }
    });
  });
}
module.exports = exports['default'];