'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

exports.default = deleteLog;

var _system = require('../../utils/system');

var _system2 = _interopRequireDefault(_system);

var _tailhelper = require('../../utils/tailhelper');

var _tailhelper2 = _interopRequireDefault(_tailhelper);

var _loggingManager = require('logging-manager');

var _devDelay = require('../../utils/devDelay.js');

var _devDelay2 = _interopRequireDefault(_devDelay);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function deleteLog(req) {
  return new _promise2.default(function (resolve, reject) {
    return (0, _devDelay2.default)(2000).then(function () {
      var _req$body = req.body;
      var groupId = _req$body.groupId;
      var logId = _req$body.logId;

      if (!groupId) {
        _loggingManager.Instance.debug('System', 'deleteLog', 'Blank group ID passed.');
        reject({
          status: 400,
          errorField: 'groupId',
          errorReason: 'No group ID was passed to log delete request.'
        });
      } else if (!logId) {
        _loggingManager.Instance.debug('System', 'deleteLog', 'Blank log ID passed.');
        reject({
          status: 400,
          errorField: 'logId',
          errorReason: 'No log ID was passed to log delete request.'
        });
      } else if (!_system2.default.groupIdIsValid(groupId)) {
        _loggingManager.Instance.debug('System', 'deleteLog', 'Invalid group ID passed: ' + groupId);
        reject({
          status: 400,
          errorField: 'groupId',
          errorReason: 'Invalid group ID was passed to log delete request. No group exists for the ID "' + groupId + '".'
        });
      } else if (!_system2.default.logIdIsValid(logId)) {
        _loggingManager.Instance.debug('System', 'deleteLog', 'Invalid log ID passed: ' + logId);
        reject({
          status: 400,
          errorField: 'logId',
          errorReason: 'Invalid log ID was passed to log delete request. No log exists for the ID "' + logId + '".'
        });
      } else {
        _loggingManager.Instance.debug('System', 'deleteLog', 'Deleting log using groupId ' + groupId + ' and logId ' + logId);
        _tailhelper2.default.killListener(logId);
        _system2.default.deleteLog(groupId, logId).then(function () {
          resolve();
        }, function (error) {
          _loggingManager.Instance.error('System', 'deleteLog', 'Error occured deleting group using groupId ' + groupId + ' and logId ' + logId);
          _loggingManager.Instance.error('System', 'deleteLog', error);
          reject({
            status: 500,
            errorField: 'logId',
            errorReason: 'An error occured while trying to delete log. Please check the config file as it may be out of sync and the application may require a restart.'
          });
        });
      }
    });
  });
}
module.exports = exports['default'];