'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

exports.default = saveGroupName;

var _system = require('../../utils/system');

var _system2 = _interopRequireDefault(_system);

var _loggingManager = require('logging-manager');

var _devDelay = require('../../utils/devDelay.js');

var _devDelay2 = _interopRequireDefault(_devDelay);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function saveGroupName(req) {
  return new _promise2.default(function (resolve, reject) {
    return (0, _devDelay2.default)(2000).then(function () {
      var _req$body = req.body;
      var newGroupName = _req$body.newGroupName;
      var groupId = _req$body.groupId;

      if (!newGroupName) {
        _loggingManager.Instance.debug('System', 'saveGroupName', 'Blank group name passed.');
        reject({
          status: 400,
          errorField: 'newGroupName',
          errorReason: 'No group name was passed to edit request.'
        });
      } else if (newGroupName.length > 15) {
        _loggingManager.Instance.debug('System', 'saveGroupName', 'Invalid group name passed: ' + newGroupName);
        reject({
          status: 400,
          errorField: 'groupName',
          errorReason: 'The group name is invalid. It must be 15 characters or less.'
        });
      } else {
        _loggingManager.Instance.debug('System', 'saveGroupName', 'Updating group name using groupId: ' + groupId + ' with new name ' + newGroupName);
        _system2.default.updateGroupName(groupId, newGroupName).then(function () {
          resolve();
        }, function (error) {
          _loggingManager.Instance.error('System', 'saveGroupName', 'Error occured saving group name change for groupId: ' + groupId + ' with new name ' + newGroupName);
          _loggingManager.Instance.error('System', 'saveGroupName', error);
          reject({
            status: 500,
            errorField: 'groupName',
            errorReason: 'An error occured while trying to save the group name change. Please check the config file as it may be out of sync and the application may require a restart.'
          });
        });
      }
    });
  });
}
module.exports = exports['default'];