'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

exports.default = saveLogChanges;

var _system = require('../../utils/system');

var _system2 = _interopRequireDefault(_system);

var _loggingManager = require('logging-manager');

var _devDelay = require('../../utils/devDelay.js');

var _devDelay2 = _interopRequireDefault(_devDelay);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function saveLogChanges(req) {
  return new _promise2.default(function (resolve, reject) {
    return (0, _devDelay2.default)(2000).then(function () {
      var _req$body = req.body;
      var logId = _req$body.logId;
      var oldGroupId = _req$body.oldGroupId;
      var editedName = _req$body.editedName;
      var editedGroupId = _req$body.editedGroupId;
      var editedFile = _req$body.editedFile;
      var editedPath = _req$body.editedPath;

      if (!editedName) {
        _loggingManager.Instance.debug('System', 'saveLogChanges', 'Blank log name passed.');
        reject({
          status: 400,
          errorField: 'newLogName',
          errorReason: 'No new log name was passed to edit log request.'
        });
      } else if (editedName.length > 15) {
        _loggingManager.Instance.debug('System', 'saveLogChanges', 'Invalid log name passed: ' + editedName);
        reject({
          status: 400,
          errorField: 'newLogName',
          errorReason: 'The new log name "' + editedName + '" is invalid. It must be 15 characters or less.'
        });
      } else if (editedGroupId && !_system2.default.groupIdIsValid(editedGroupId)) {
        _loggingManager.Instance.debug('System', 'saveLogChanges', 'Invalid group ID passed.');
        reject({
          status: 400,
          errorField: 'newGroupId',
          errorReason: 'Invalid new group ID was passed to edit log request. No group exists for that ID.'
        });
      } else if (!editedFile) {
        _loggingManager.Instance.debug('System', 'saveLogChanges', 'Blank log file name passed.');
        reject({
          status: 400,
          errorField: 'newLogFile',
          errorReason: 'No new log file name was passed to edit log request.'
        });
      } else if (editedFile.length > 1000) {
        _loggingManager.Instance.debug('System', 'saveLogChanges', 'Invalid log file passed: ' + editedFile);
        reject({
          status: 400,
          errorField: 'newLogFile',
          errorReason: 'The new log file name "' + editedFile + '" is invalid. It must be 1000 characters or less.'
        });
      } else if (!editedPath) {
        _loggingManager.Instance.debug('System', 'saveLogChanges', 'Blank log path passed.');
        reject({
          status: 400,
          errorField: 'newLogPath',
          errorReason: 'No new log file path was passed to edit log request.'
        });
      } else if (editedPath.length > 1000) {
        _loggingManager.Instance.debug('System', 'saveLogChanges', 'Invalid log file path passed: ' + editedPath);
        reject({
          status: 400,
          errorField: 'newLogPath',
          errorReason: 'The new log file path "' + editedPath + '" is invalid. It must be 1000 characters or less.'
        });
      } else {
        _loggingManager.Instance.debug('System', 'saveLogChanges', 'Editing log with ID: ' + logId);
        _system2.default.updateLog(logId, oldGroupId, editedName, editedGroupId, editedFile, editedPath).then(function () {
          resolve();
        }, function (error) {
          _loggingManager.Instance.error('System', 'saveLogChanges', 'Error occured editing log with ID: ' + logId);
          _loggingManager.Instance.error('System', 'saveLogChanges', error);
          reject({
            status: 500,
            errorField: 'newLogName',
            errorReason: 'An error occured while trying to edit the log. Please check the config file as it may be out of sync and the application may require a restart.'
          });
        });
      }
    });
  });
}
module.exports = exports['default'];