'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

exports.default = saveSystemSettings;

var _system = require('../../utils/system');

var _system2 = _interopRequireDefault(_system);

var _loggingManager = require('logging-manager');

var _devDelay = require('../../utils/devDelay.js');

var _devDelay2 = _interopRequireDefault(_devDelay);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// TODO ## : Add a way of extracting this from the logging-manager
var validLogLevels = ['SYSTEM', 'FATAL', 'ERROR', 'INFO', 'DEBUG', 'TRACE'];

function validatePort(portValue) {
  return !isNaN(parseInt(portValue, 10)) && portValue % 1 === 0 && portValue >= 0 && portValue <= 65535;
}

function saveSystemSettings(req) {
  return new _promise2.default(function (resolve, reject) {
    return (0, _devDelay2.default)(2000).then(function () {
      var newWebPort = req.body.newWebPort;
      var newApiPort = req.body.newApiPort;
      var newLogLevel = req.body.newLogLevel;

      if (!validatePort(newWebPort)) {
        _loggingManager.Instance.debug('System', 'saveSystemSettings', 'Invalid web port passed: ' + newWebPort);
        reject({
          status: 400,
          errorField: 'webport',
          errorReason: 'The Web Port you provided is invalid. It should be an interger in the range 0 to 65535.'
        });
      } else if (!validatePort(newApiPort)) {
        _loggingManager.Instance.debug('System', 'saveSystemSettings', 'Invalid api port passed: ' + newApiPort);
        reject({
          status: 400,
          errorField: 'apiport',
          errorReason: 'The API Port you provided is invalid. It should be an interger in the range 0 to 65535.'
        });
      } else if (newWebPort === newApiPort) {
        _loggingManager.Instance.debug('System', 'saveSystemSettings', 'Same value passed for both ports: ' + newWebPort);
        reject({
          status: 401,
          errorField: 'apiport',
          errorReason: 'The API port and Web port must be different values.'
        });
      } else if (! ~validLogLevels.indexOf(newLogLevel)) {
        _loggingManager.Instance.debug('System', 'saveSystemSettings', 'Invalid log level passed: ' + newLogLevel);
        reject({
          status: 401,
          errorField: 'loglevel',
          errorReason: 'The Log Level you provided is invalid. Please select one of the values provided.'
        });
      } else {
        _loggingManager.Instance.info('System', 'saveSystemSettings', 'Updating System settings.');
        _system2.default.updateSystemSettings(newWebPort, newApiPort, newLogLevel).then(function () {
          resolve();
        }, function (error) {
          _loggingManager.Instance.error('System', 'saveSystemSettings', 'Error occured saving system settings change.');
          _loggingManager.Instance.error('System', 'saveSystemSettings', error);
          reject({
            status: 500,
            errorField: 'untraceable',
            errorReason: 'An error occured while trying to save the app settings changes to the system config file. Please check the config file as it may be out of sync and the application may require a restart.'
          });
        });
      }
    });
  });
}
module.exports = exports['default'];