'use strict';

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _express = require('express');

var _express2 = _interopRequireDefault(_express);

var _expressSession = require('express-session');

var _expressSession2 = _interopRequireDefault(_expressSession);

var _bodyParser = require('body-parser');

var _bodyParser2 = _interopRequireDefault(_bodyParser);

var _config = require('../src/config');

var _config2 = _interopRequireDefault(_config);

var _index = require('./actions/index');

var actions = _interopRequireWildcard(_index);

var _url = require('./utils/url.js');

var _prettyError = require('pretty-error');

var _prettyError2 = _interopRequireDefault(_prettyError);

var _http = require('http');

var _http2 = _interopRequireDefault(_http);

var _socket = require('socket.io');

var _socket2 = _interopRequireDefault(_socket);

var _system = require('./utils/system.js');

var _system2 = _interopRequireDefault(_system);

var _tailhelper = require('./utils/tailhelper.js');

var _tailhelper2 = _interopRequireDefault(_tailhelper);

var _loggingManager = require('logging-manager');

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// const tailHelper = new TailHelper();
var pretty = new _prettyError2.default();
var app = (0, _express2.default)();

var server = new _http2.default.Server(app);

var io = new _socket2.default(server);
io.path('/ws');

_system2.default.setSocketIo(io);
_tailhelper2.default.setSocketIo(io);

app.use((0, _expressSession2.default)({
  secret: 'react and redux rule!!!!',
  resave: false,
  saveUninitialized: false,
  cookie: { maxAge: 600000 }
}));
app.use(_bodyParser2.default.json());

app.use(function (req, res) {
  _loggingManager.Instance.trace('API', 'main', 'Incoming API request at URL: ' + req.url);
  var splittedUrlPath = req.url.split('?')[0].split('/').slice(1);

  var _mapUrl = (0, _url.mapUrl)(actions, splittedUrlPath);

  var action = _mapUrl.action;
  var params = _mapUrl.params;

  if (action) {
    action(req, params).then(function (result) {
      if (result instanceof Function) {
        result(res);
      } else {
        res.json(result);
      }
    }, function (reason) {
      if (reason && reason.redirect) {
        res.redirect(reason.redirect);
      } else {
        _loggingManager.Instance.error('API', 'main', 'API error:');
        _loggingManager.Instance.error('API', 'main', pretty.render(reason));
        res.status(reason.status || 500).json(reason);
      }
    });
  } else {
    res.status(404).end('NOT FOUND');
  }
});

var bufferSize = 100;
var messageBuffer = new Array(bufferSize);
var messageIndex = 0;

var socketSessions = {};

if (_config2.default.apiPort) {
  var runnable = app.listen(_config2.default.apiPort, function (err) {
    if (err) {
      _loggingManager.Instance.fatal('API', 'main', 'Error starting API server.');
      _loggingManager.Instance.fatal('API', 'main', err);
      process.exit(1);
    }
    _loggingManager.Instance.system('API', 'main', 'API is running on port ' + _config2.default.apiPort);
    _loggingManager.Instance.system('API', 'main', 'Send requests to http://' + _config2.default.apiHost + ':' + _config2.default.apiPort);
  });

  io.on('connection', function (socket) {
    _loggingManager.Instance.trace('API', 'main', 'SOCKET connected');

    socket.on('history', function () {
      for (var index = 0; index < bufferSize; index++) {
        var msgNo = (messageIndex + index) % bufferSize;
        var msg = messageBuffer[msgNo];
        if (msg) {
          socket.emit('msg', msg);
        }
      }
    });

    socket.on('msg', function (data) {
      data.id = messageIndex;
      messageBuffer[messageIndex % bufferSize] = data;
      messageIndex++;
      io.emit('msg', data);
    });

    socketSessions[socket.id] = [];

    socket.on('attachLogListener', function (data) {
      _loggingManager.Instance.trace('API', 'main', 'SOCKET attachLogListener: ' + (0, _stringify2.default)(data));
      var error = _tailhelper2.default.attachListener(io, socket, data.logId);
      if (!error) {
        socketSessions[socket.id].push({
          logId: data.logId
        });
      } else {
        socket.emit('tail:failure', (0, _extends3.default)({}, error, data));
      }
    });

    socket.on('detachLogListener', function (data) {
      _loggingManager.Instance.trace('API', 'main', 'SOCKET detachLogListener: ' + (0, _stringify2.default)(data));
      _tailhelper2.default.detachListener(socket, data.logId);
      var toRemove = undefined;
      socketSessions[socket.id].forEach(function (item, index) {
        if (item.logId === data.logId) {
          toRemove = index;
        }
      });
      // Have to explictly check !== undefined here because toRemove === 0 is a valid result
      if (toRemove !== undefined) {
        socketSessions[socket.id].splice(toRemove, 1);
      }
    });

    socket.on('disconnect', function () {
      _loggingManager.Instance.trace('API', 'main', 'SOCKET disconnected');
      socketSessions[socket.id].forEach(function (item) {
        _tailhelper2.default.detachListener(socket, item.logId);
      });
      delete socketSessions[socket.id];
    });
  });
  io.listen(runnable);
} else {
  _loggingManager.Instance.fatal('API', 'main', 'No PORT environment variable has been specified');
  process.exit(1);
}