'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _bcryptNodejs = require('bcrypt-nodejs');

var _bcryptNodejs2 = _interopRequireDefault(_bcryptNodejs);

var _loggingManager = require('logging-manager');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint func-names:0 */

function readFile(file) {
  return new _promise2.default(function (resolve, reject) {
    _fs2.default.readFile(file, 'utf-8', function (err, data) {
      if (err) reject(err);else resolve(JSON.parse(data));
    });
  });
}

function writeFile(file, contents) {
  return new _promise2.default(function (resolve, reject) {
    _fs2.default.writeFile(file, contents, 'utf-8', function (err) {
      if (err) reject(err);else resolve();
    });
  });
}

var SystemHelper = function SystemHelper() {
  var _this = this;

  (0, _classCallCheck3.default)(this, SystemHelper);

  this.setSocketIo = function (io) {
    _this.socketio = io;
  };

  this.saveConfigToDisk = function () {
    _loggingManager.Instance.debug('SystemHelper', 'saveConfigToDisk', 'Writing system file to disk');
    return writeFile(_this.fileLocation, (0, _stringify2.default)(_this.system, null, 2)).then(function () {
      _loggingManager.Instance.debug('SystemHelper', 'saveConfigToDisk', 'Finished writing system file to disk');
    }).catch(function (error) {
      _loggingManager.Instance.fatal('SystemHelper', 'saveConfigToDisk', 'Failed to write file to disk');
      _loggingManager.Instance.fatal('SystemHelper', 'saveConfigToDisk', error);
      return _promise2.default.reject(error);
    });
  };

  this.getAppSettings = function () {
    return _this.system.app;
  };

  this.getGroups = function () {
    return _this.system.groups;
  };

  this.getLogs = function () {
    return _this.system.logs;
  };

  this.checkForUser = function (username) {
    return !!_this.system.users[username];
  };

  this.checkUserPassword = function (username, password) {
    return new _promise2.default(function (resolve, reject) {
      _bcryptNodejs2.default.compare(password, _this.system.users[username].passhash, function (err, result) {
        if (err) reject(err);else resolve(result);
      });
    });
  };

  this.getLogNameById = function (logId) {
    return _this.system.logs[logId].name;
  };

  this.getLogFile = function (logId) {
    var log = _this.system.logs[logId];
    return log.fpath + log.fname;
  };

  this.updateSystemSettings = function (newWebPort, newApiPort, newLogLevel) {
    _this.system.app = (0, _extends3.default)({}, _this.system.app, {
      webport: newWebPort,
      apiport: newApiPort,
      loglevel: newLogLevel
    });
    _loggingManager.Instance.setLogLevel(newLogLevel);
    return _this.saveConfigToDisk();
  };

  this.updateGroupName = function (groupId, newName) {
    var oldName = _this.system.groups[groupId].name;
    _loggingManager.Instance.debug('SystemHelper', 'updateGroupName', 'Updating group name using groupId: ' + groupId + ' from "' + oldName + '" to newName: ' + newName);
    _this.system.groups[groupId].name = newName;
    return _this.saveConfigToDisk().then(function () {
      // Emit updated group to all sessions including the guy that updated the group
      _this.socketio.emit('group:nameChange', { groupId: groupId, newName: newName, oldName: oldName });
    });
  };

  this.groupIdIsValid = function (groupId) {
    _loggingManager.Instance.debug('SystemHelper', 'groupIdIsValid', 'Checking groupId: ' + groupId);
    return !!_this.system.groups[groupId];
  };

  this.logIdIsValid = function (logId) {
    _loggingManager.Instance.debug('SystemHelper', 'logIdIsValid', 'Checking logId: ' + logId);
    return !!_this.system.logs[logId];
  };

  this.deleteGroup = function (groupId) {
    _loggingManager.Instance.debug('SystemHelper', 'deleteGroup', 'Deleting group using groupId: ' + groupId);
    var groupName = _this.system.groups[groupId].name;
    var logIds = _this.system.groups[groupId].logs;
    _this.system.groups[groupId].logs.forEach(function (logId) {
      delete _this.system.logs[logId];
    });
    delete _this.system.groups[groupId];
    return _this.saveConfigToDisk().then(function () {
      // Emit deleted group to all sessions including the guy that deleted the group
      _loggingManager.Instance.debug('SystemHelper', 'deleteGroup', 'Emitting delete group for: ' + groupId);
      _this.socketio.emit('group:groupDelete', { groupId: groupId, logIds: logIds, groupName: groupName });
    });
  };

  this.createGroup = function (newGroupName) {
    _loggingManager.Instance.debug('SystemHelper', 'createGroup', 'Creating new group using name: ' + newGroupName);

    // Get new ID:
    var currentKeys = (0, _keys2.default)(_this.system.groups).map(function (key) {
      return parseInt(key, 10);
    }).sort(function (first, second) {
      return first > second;
    });
    var newGroupId = (currentKeys.pop() || 0) + 1;
    _loggingManager.Instance.debug('SystemHelper', 'createGroup', 'Allocated group ID: ' + newGroupId);

    // Create group
    _this.system.groups[newGroupId] = {
      name: newGroupName,
      logs: []
    };
    return _this.saveConfigToDisk().then(function () {
      // Emit new group to all sessions including the guy that created the group
      _this.socketio.emit('group:newGroup', { newGroupId: newGroupId, newGroupName: newGroupName });
    });
  };

  this.createLog = function (logName, groupId, logFile, logPath) {
    _loggingManager.Instance.debug('SystemHelper', 'createLog', 'Creating log using: ' + logName + ' ' + groupId + ' ' + logFile + ' ' + logPath);

    // Get new ID:
    var currentKeys = (0, _keys2.default)(_this.system.logs).map(function (key) {
      return parseInt(key, 10);
    }).sort(function (first, second) {
      return first > second;
    });
    var newLogId = (currentKeys.pop() || 0) + 1;
    _loggingManager.Instance.debug('SystemHelper', 'createGroup', 'Allocated log ID: ' + newLogId);

    // Create log
    _this.system.logs[newLogId] = {
      name: logName,
      fname: logFile,
      fpath: logPath
    };
    // Add reference in group
    _this.system.groups[groupId].logs.push('' + newLogId);
    var groupName = _this.system.groups[groupId].name;
    return _this.saveConfigToDisk().then(function () {
      // Emit new log to all sessions including the guy that created the log
      _this.socketio.emit('log:newLog', { newLogId: newLogId, logName: logName, groupId: groupId, logFile: logFile, logPath: logPath, groupName: groupName });
    });
  };

  this.deleteLog = function (groupId, logId) {
    _loggingManager.Instance.debug('SystemHelper', 'deleteLog', 'Deleting log using groupId: ' + groupId + ' and logId: ' + logId);
    var logName = _this.system.logs[logId].name;
    var groupName = _this.system.groups[groupId].name;
    delete _this.system.logs[logId];
    _this.system.groups[groupId].logs = _this.system.groups[groupId].logs.filter(function (filterLogId) {
      return filterLogId !== logId;
    });
    return _this.saveConfigToDisk().then(function () {
      // Emit deleted log to all sessions including the guy that deleted the log
      _this.socketio.emit('log:logDelete', { groupId: groupId, logId: logId, logName: logName, groupName: groupName });
    });
  };

  this.updateLog = function (logId, oldGroupId, editedName, editedGroupId, editedFile, editedPath) {
    _loggingManager.Instance.debug('SystemHelper', 'updateLog', 'Editing log using log ID: ' + logId);

    var oldName = _this.system.logs[logId].name;
    var oldFile = _this.system.logs[logId].fname;
    var oldPath = _this.system.logs[logId].fpath;

    var oldGroupName = undefined;
    var newGroupName = undefined;

    if (oldName !== editedName) {
      _this.system.logs[logId].name = editedName;
    }
    if (editedGroupId && oldGroupId !== editedGroupId) {
      // Save names for notification
      oldGroupName = _this.system.groups[oldGroupId].name;
      newGroupName = _this.system.groups[editedGroupId].name;
      // Make config changes
      _this.system.groups[oldGroupId].logs = _this.system.groups[oldGroupId].logs.filter(function (id) {
        return id !== logId;
      });
      _this.system.groups[editedGroupId].logs.push(logId);
    }
    if (oldFile !== editedFile) {
      _this.system.logs[logId].fname = editedFile;
    }
    if (oldPath !== editedPath) {
      _this.system.logs[logId].fpath = editedPath;
    }

    return _this.saveConfigToDisk().then(function () {
      // Emit log changes to all sessions including the guy that edited the log
      if (oldName !== editedName) {
        _this.socketio.emit('log:nameChange', { logId: logId, newName: editedName, oldName: oldName });
      }
      if (editedGroupId && oldGroupId !== editedGroupId) {
        _this.socketio.emit('log:groupChange', { logId: logId, logName: editedName, newGroupName: newGroupName, oldGroupName: oldGroupName, newGroupId: editedGroupId, oldGroupId: oldGroupId });
      }
      if (oldFile !== editedFile) {
        _this.socketio.emit('log:fileChange', { logId: logId, logName: editedName, newFile: editedFile, oldFile: oldFile });
      }
      if (oldPath !== editedPath) {
        _this.socketio.emit('log:pathChange', { logId: logId, logName: editedName, newPath: editedPath, oldPath: oldPath });
      }
    });
  };

  _loggingManager.Instance.system('SystemHelper', 'constructor', 'Initialising SystemHelper, reading config file...');
  this.fileLocation = global.__CONFIG_FILE__;
  readFile(this.fileLocation).then(function (data) {
    _loggingManager.Instance.system('SystemHelper', 'constructor', 'Finished reading system file');
    _this.system = data;

    // Check that the essentials are there
    var configChanged = false;

    if (!_this.system.app) {
      _this.system.app = {
        webport: 8080,
        apiport: 3030,
        loglevel: 'ERROR',
        fakeWebSockets: false
      };
      configChanged = true;
    }

    if (!_this.system.users) {
      _this.system.users = {};
      configChanged = true;
    }

    if (!_this.system.groups) {
      _this.system.groups = {};
      configChanged = true;
    }

    if (!_this.system.logs) {
      _this.system.logs = {};
      configChanged = true;
    }

    if (configChanged) {
      _loggingManager.Instance.info('SystemHelper', 'constructor', 'Config file was missing some properties, defaults are being added.');
      return _this.saveConfigToDisk();
    }
  }).catch(function (error) {
    _loggingManager.Instance.fatal('SystemHelper', 'constructor', 'Failed to read system file');
    _loggingManager.Instance.fatal('SystemHelper', 'constructor', error);
    process.exit(1);
  });
};

var instance = new SystemHelper();

exports.default = instance;
module.exports = exports['default'];