'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _tail = require('tail');

var _system = require('./system.js');

var _system2 = _interopRequireDefault(_system);

var _loggingManager = require('logging-manager');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var TailHelper = function TailHelper() {
  var _this = this;

  (0, _classCallCheck3.default)(this, TailHelper);

  this.setSocketIo = function (io) {
    _this.io = io;
  };

  this.attachListener = function (io, socket, logId) {
    var file = _system2.default.getLogFile(logId);
    if (!_this.activeSessions[logId]) {
      _loggingManager.Instance.debug('TailHelper', 'attachListener', 'Creating new session for logId: ' + logId);

      var tailer = undefined;
      try {
        tailer = new _tail.Tail(file);
      } catch (error) {
        _loggingManager.Instance.error('TailHelper', 'attachListener', 'Cannot tail file: ' + file);
        _loggingManager.Instance.error('TailHelper', 'attachListener', 'Error code: ' + error.code);

        var reason = undefined;
        if (error.code === 'EACCES') {
          reason = 'The server was unable to tail log "' + _system2.default.getLogNameById(logId) + '" due to insufficient permissions.';
        } else if (error.code === 'ENOENT') {
          reason = 'The log file for "' + _system2.default.getLogNameById(logId) + '" could not be found. Please check that the path and name are correct.';
        } else {
          reason = 'An error occured trying to tail log "' + _system2.default.getLogNameById(logId) + '".';
        }

        return {
          errorCode: error.code,
          errorReason: reason
        };
      }

      tailer.on('error', function (error) {
        _loggingManager.Instance.debug('TailHelper', 'tailerOnError', 'For file: ' + file + ' - ' + error);
      });

      tailer.on('line', function (data) {
        _loggingManager.Instance.trace('TailHelper', 'tailerOnLine', 'For file: ' + file + ' - ' + data);
        io.to('listenerFor_' + logId).emit('lineUpdate', {
          logId: logId,
          newLine: data
        });
      });

      _this.activeSessions[logId] = {
        listeners: 0,
        tailer: tailer
      };
    }

    _this.activeSessions[logId].listeners++;
    socket.join('listenerFor_' + logId);

    return null;
  };

  this.detachListener = function (socket, logId) {
    _loggingManager.Instance.debug('TailHelper', 'detachListener', 'Detaching listener for logId: ' + logId);

    if (!!_this.activeSessions[logId] && _this.activeSessions[logId].listeners === 1) {
      _loggingManager.Instance.debug('TailHelper', 'detachListener', 'Destroying watcher entry');
      _this.activeSessions[logId].tailer.unwatch();
      delete _this.activeSessions[logId];
    } else {
      _this.activeSessions[logId].listeners -= 1;
    }

    socket.leave('listenerFor_' + logId);
  };

  this.killListener = function (logId) {
    // This function will detach all active listeners and clear the Tailer when a log is deleted
    _loggingManager.Instance.debug('TailHelper', 'killListener', 'Killing listener for logId: ' + logId);

    if (!!_this.activeSessions[logId]) {
      // Kill the tailer so no more lines trigger
      _this.activeSessions[logId].tailer.unwatch();
      delete _this.activeSessions[logId];
      _loggingManager.Instance.trace('TailHelper', 'killListener', 'Tailer removed');
      // Remove all sockets from the room
      (0, _keys2.default)(_this.io.sockets.adapter.rooms['listenerFor_' + logId].sockets).forEach(function (socketId) {
        return _this.io.sockets.connected[socketId].leave('listenerFor_' + logId);
      });
      _loggingManager.Instance.trace('TailHelper', 'killListener', 'Room cleared');
    } else {
      _loggingManager.Instance.trace('TailHelper', 'killListener', 'Log was not active');
    }
  };

  this.activeSessions = {};
};

var instance = new TailHelper();

exports.default = instance;
module.exports = exports['default'];