'use strict';

var _chai = require('chai');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactRouter = require('react-router');

var _makeRouteHooksSafe = require('../makeRouteHooksSafe');

var _makeRouteHooksSafe2 = _interopRequireDefault(_makeRouteHooksSafe);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('makeRouteHooksSafe', function () {
  it('should work with JSX routes', function () {
    var onEnter = function onEnter() {
      throw new Error('Shouldn\'t call onEnter');
    };

    var getRoutes = (0, _makeRouteHooksSafe2.default)(function () {
      return _react2.default.createElement(
        _reactRouter.Route,
        { path: '/' },
        _react2.default.createElement(_reactRouter.IndexRoute, { onEnter: onEnter }),
        _react2.default.createElement(_reactRouter.Route, { path: '1' }),
        _react2.default.createElement(
          _reactRouter.Route,
          { onEnter: onEnter },
          _react2.default.createElement(_reactRouter.Route, { path: '2' }),
          _react2.default.createElement(_reactRouter.Route, { path: '3', onEnter: onEnter })
        )
      );
    });

    var routes = getRoutes(null);

    (0, _chai.expect)(routes[0].indexRoute.onEnter).to.not.throw(Error);
    (0, _chai.expect)(routes[0].childRoutes[1].onEnter).to.not.throw(Error);
    (0, _chai.expect)(routes[0].childRoutes[1].childRoutes[1].onEnter).to.not.throw(Error);
  });

  it('should work with JS routes', function () {
    var onEnter = function onEnter() {
      throw new Error('Shouldn\'t call onEnter');
    };

    var getRoutes = (0, _makeRouteHooksSafe2.default)(function () {
      return {
        path: '/',
        indexRoute: {
          onEnter: onEnter
        },
        onEnter: onEnter,
        childRoutes: [{ path: '1' }, {
          onEnter: onEnter,
          childRoutes: [{ path: '2' }, { path: '3' }]
        }]
      };
    });

    var routes = getRoutes(null);

    (0, _chai.expect)(routes[0].indexRoute.onEnter).to.not.throw(Error);
    (0, _chai.expect)(routes[0].onEnter).to.not.throw(Error);
    (0, _chai.expect)(routes[0].childRoutes[1].onEnter).to.not.throw(Error);
  });

  it('should call onEnter if store is initialised', function (done) {
    var store = {
      getState: function getState() {}
    };

    var getRoutes = (0, _makeRouteHooksSafe2.default)(function () {
      return {
        onEnter: function onEnter() {
          done();
        }
      };
    });

    var routes = getRoutes(store);

    routes[0].onEnter();
  });

  it('should call callback', function (done) {
    var getRoutes = (0, _makeRouteHooksSafe2.default)(function () {
      return {
        onEnter: function onEnter(nextState, replaceState, cb) {} // eslint-disable-line no-unused-vars
      };
    });

    var routes = getRoutes(null);

    routes[0].onEnter(null, null, done);
  });

  it('should not call callback', function () {
    var callback = function callback() {
      throw new Error('Should not be called');
    };

    var getRoutes = (0, _makeRouteHooksSafe2.default)(function () {
      return {
        onEnter: function onEnter(nextState, replaceState) {} // eslint-disable-line no-unused-vars
      };
    });

    var routes = getRoutes(null);

    routes[0].onEnter(null, null, callback);
  });
});