'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

exports.default = appManagement;
exports.isLoaded = isLoaded;
exports.load = load;
exports.editWebPort = editWebPort;
exports.editApiPort = editApiPort;
exports.editLogLevel = editLogLevel;
exports.resetChanges = resetChanges;
exports.saveChanges = saveChanges;

var _sharedActions = require('./sharedActions.js');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var LOAD = 'logger-app/appManagement/LOAD';
var LOAD_SUCCESS = 'logger-app/appManagement/LOAD_SUCCESS';
var LOAD_FAIL = 'logger-app/appManagement/LOAD_FAIL';
var EDIT_WEB_PORT = 'logger-app/appManagement/EDIT_WEB_PORT';
var EDIT_API_PORT = 'logger-app/appManagement/EDIT_API_PORT';
var EDIT_LOG_LEVEL = 'logger-app/appManagement/EDIT_LOG_LEVEL';
var RESET_CHANGES = 'logger-app/appManagement/RESET_CHANGES';
var APP_MANAGMENT_SAVE = 'logger-app/appManagement/SAVE';

var initialState = {
  loaded: false
};

function appManagement() {
  var state = arguments.length <= 0 || arguments[0] === undefined ? initialState : arguments[0];
  var action = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

  switch (action.type) {
    case LOAD:
      return (0, _extends3.default)({}, state, {
        loading: true
      });
    case LOAD_SUCCESS:
      return (0, _extends3.default)({}, state, {
        loading: false,
        loaded: true,
        data: (0, _extends3.default)({}, action.result, {
          editableWebPort: action.result.webport,
          editableApiPort: action.result.apiport,
          editableLogLevel: action.result.loglevel
        }),
        error: null
      });
    case LOAD_FAIL:
      return (0, _extends3.default)({}, state, {
        loading: false,
        loaded: false,
        data: null,
        error: action.error
      });
    case EDIT_WEB_PORT:
      return (0, _extends3.default)({}, state, {
        data: (0, _extends3.default)({}, state.data, {
          editableWebPort: parseInt(action.newWebPort.replace(/[^0-9]/g, '').substring(0, 5), 10) || ''
        })
      });
    case EDIT_API_PORT:
      return (0, _extends3.default)({}, state, {
        data: (0, _extends3.default)({}, state.data, {
          editableApiPort: parseInt(action.newApiPort.replace(/[^0-9]/g, '').substring(0, 5), 10) || ''
        })
      });
    case EDIT_LOG_LEVEL:
      return (0, _extends3.default)({}, state, {
        data: (0, _extends3.default)({}, state.data, {
          editableLogLevel: action.newLogLevel
        })
      });
    case RESET_CHANGES:
      return (0, _extends3.default)({}, state, {
        data: (0, _extends3.default)({}, state.data, {
          editableWebPort: state.data.webport,
          editableApiPort: state.data.apiport,
          editableLogLevel: state.data.loglevel
        })
      });
    case APP_MANAGMENT_SAVE:
      return (0, _extends3.default)({}, state, {
        saving: true
      });
    case _sharedActions.APP_MANAGMENT_SAVE_FAIL:
      return (0, _extends3.default)({}, state, {
        saving: false
      });
    case _sharedActions.APP_MANAGMENT_SAVE_SUCCESS:
      return (0, _extends3.default)({}, state, {
        saving: false,
        data: (0, _extends3.default)({}, state.data, {
          webport: state.data.editableWebPort,
          apiport: state.data.editableApiPort,
          loglevel: state.data.editableLogLevel
        })
      });
    default:
      return state;
  }
}

function isLoaded(globalState) {
  return globalState.appManagement && globalState.appManagement.loaded;
}

function load() {
  return {
    types: [LOAD, LOAD_SUCCESS, LOAD_FAIL],
    promise: function promise(client) {
      return client.get('/system/getAppSettings');
    }
  };
}

function editWebPort(newWebPort) {
  return {
    type: EDIT_WEB_PORT,
    newWebPort: newWebPort
  };
}

function editApiPort(newApiPort) {
  return {
    type: EDIT_API_PORT,
    newApiPort: newApiPort
  };
}

function editLogLevel(newLogLevel) {
  return {
    type: EDIT_LOG_LEVEL,
    newLogLevel: newLogLevel
  };
}

function resetChanges() {
  return {
    type: RESET_CHANGES
  };
}

function saveChanges(newWebPort, newApiPort, newLogLevel) {
  return {
    types: [APP_MANAGMENT_SAVE, _sharedActions.APP_MANAGMENT_SAVE_SUCCESS, _sharedActions.APP_MANAGMENT_SAVE_FAIL],
    promise: function promise(client) {
      return client.post('/system/saveSystemSettings', {
        data: {
          newWebPort: newWebPort,
          newApiPort: newApiPort,
          newLogLevel: newLogLevel
        }
      });
    }
  };
}