'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _defineProperty2 = require('babel-runtime/helpers/defineProperty');

var _defineProperty3 = _interopRequireDefault(_defineProperty2);

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _extends6 = require('babel-runtime/helpers/extends');

var _extends7 = _interopRequireDefault(_extends6);

exports.default = groups;
exports.isLoaded = isLoaded;
exports.load = load;
exports.toggleNavGroupOpen = toggleNavGroupOpen;
exports.setGroupListFilter = setGroupListFilter;
exports.toggleEditNameOpen = toggleEditNameOpen;
exports.setEditedName = setEditedName;
exports.saveGroupName = saveGroupName;
exports.toggleDeleteGroupOpen = toggleDeleteGroupOpen;
exports.deleteGroup = deleteGroup;

var _sharedActions = require('./sharedActions.js');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var INITIAL_LOAD = 'logger-app/groups/INITIAL_LOAD';
var INITIAL_LOAD_SUCCESS = 'logger-app/groups/INITIAL_LOAD_SUCCESS';
var INITIAL_LOAD_FAIL = 'logger-app/groups/INITIAL_LOAD_FAIL';

var TOGGLE_NAV_GROUP_OPEN = 'logger-app/groups/TOGGLE_NAV_GROUP_OPEN';
var SET_GROUP_LIST_FILTER = 'logger-app/groups/SET_GROUP_LIST_FILTER';

// Group Management actions
// Edit Group Name
var TOGGLE_EDIT_NAME_OPEN = 'logger-app/groups/TOGGLE_EDIT_NAME_OPEN';
var SET_EDITED_NAME = 'logger-app/groups/SET_EDITED_NAME';
var SAVE_GROUP_NAME = 'logger-app/groups/SAVE_GROUP_NAME';
var SAVE_GROUP_NAME_SUCCESS = 'logger-app/groups/SAVE_GROUP_NAME_SUCCESS';
// Delete Group
var TOGGLE_DELETE_GROUP_OPEN = 'logger-app/groups/TOGGLE_DELETE_GROUP_OPEN';
var DELETE_GROUP = 'logger-app/groups/DELETE_GROUP';
var DELETE_GROUP_SUCCESS = 'logger-app/groups/DELETE_GROUP_SUCCESS';

// Shared Socket and API Events

var initialState = {
  loaded: false
};

var applyDefaultGroupValues = function applyDefaultGroupValues(group) {
  return (0, _extends7.default)({}, group, {
    navOpen: true,
    listFilter: '',
    editNameOpen: false,
    editedName: group.name,
    editSaving: false,
    editedNameHasError: false,
    deleteGroupOpen: false,
    deleteSaving: false
  });
};

var groupReducer = function groupReducer(state, action) {
  switch (action.type) {
    case TOGGLE_NAV_GROUP_OPEN:
      return (0, _extends7.default)({}, state, {
        navOpen: !state.navOpen
      });
    case SET_GROUP_LIST_FILTER:
      return (0, _extends7.default)({}, state, {
        listFilter: action.newListFilter
      });
    case TOGGLE_EDIT_NAME_OPEN:
      return (0, _extends7.default)({}, state, {
        editNameOpen: !state.editNameOpen
      });
    case SET_EDITED_NAME:
      return (0, _extends7.default)({}, state, {
        editedName: action.name,
        editedNameHasError: false
      });
    case SAVE_GROUP_NAME:
      return (0, _extends7.default)({}, state, {
        editSaving: true
      });
    case SAVE_GROUP_NAME_SUCCESS:
      return (0, _extends7.default)({}, state, {
        name: state.editedName,
        editNameOpen: false,
        editSaving: false
      });
    case _sharedActions.SAVE_GROUP_NAME_FAIL:
      return (0, _extends7.default)({}, state, {
        editSaving: false,
        editedNameHasError: true
      });
    case TOGGLE_DELETE_GROUP_OPEN:
      return (0, _extends7.default)({}, state, {
        deleteGroupOpen: !state.deleteGroupOpen
      });
    case DELETE_GROUP:
      return (0, _extends7.default)({}, state, {
        deleteSaving: true
      });
    case _sharedActions.DELETE_GROUP_FAIL:
      return (0, _extends7.default)({}, state, {
        deleteSaving: false
      });
    case _sharedActions.GROUP_NAME_CHANGE_EMITTED:
      return (0, _extends7.default)({}, state, {
        name: action.newName
      });
    case _sharedActions.NEW_LOG_EMITTED:
      return (0, _extends7.default)({}, state, {
        logs: [].concat((0, _toConsumableArray3.default)(state.logs), [action.newLogId])
      });
    case _sharedActions.LOG_DELETE_EMITTED:
      return (0, _extends7.default)({}, state, {
        logs: state.logs.filter(function (logId) {
          return logId !== action.logId;
        })
      });
    default:
      return state;
  }
};

function groups() {
  var _extends4;

  var state = arguments.length <= 0 || arguments[0] === undefined ? initialState : arguments[0];
  var action = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

  switch (action.type) {
    case INITIAL_LOAD:
      return (0, _extends7.default)({}, state, {
        loading: true
      });
    case INITIAL_LOAD_SUCCESS:
      return (0, _extends7.default)({}, state, {
        loading: false,
        loaded: true,
        data: (0, _keys2.default)(action.result).reduce(function (prev, groupId) {
          return (0, _extends7.default)({}, prev, (0, _defineProperty3.default)({}, groupId, applyDefaultGroupValues(action.result[groupId])));
        }, {}),
        error: null
      });
    case INITIAL_LOAD_FAIL:
      return (0, _extends7.default)({}, state, {
        loading: false,
        loaded: false,
        data: null,
        error: action.error
      });
    case DELETE_GROUP_SUCCESS:
    case _sharedActions.GROUP_DELETE_EMITTED:
      var _state$data = state.data;
      var omit = _state$data[action.groupId];
      var others = (0, _objectWithoutProperties3.default)(_state$data, [action.groupId]);

      return (0, _extends7.default)({}, state, {
        data: others
      });
    case _sharedActions.NEW_GROUP_EMITTED:
      return (0, _extends7.default)({}, state, {
        data: (0, _extends7.default)({}, state.data, (0, _defineProperty3.default)({}, action.newGroupId, applyDefaultGroupValues({ name: action.newGroupName, logs: [] })))
      });
    case _sharedActions.LOG_GROUP_CHANGE_EMITTED:
      return (0, _extends7.default)({}, state, {
        data: (0, _extends7.default)({}, state.data, (_extends4 = {}, (0, _defineProperty3.default)(_extends4, action.oldGroupId, (0, _extends7.default)({}, state.data[action.oldGroupId], {
          logs: state.data[action.oldGroupId].logs.filter(function (id) {
            return id !== action.logId;
          })
        })), (0, _defineProperty3.default)(_extends4, action.newGroupId, (0, _extends7.default)({}, state.data[action.newGroupId], {
          logs: [].concat((0, _toConsumableArray3.default)(state.data[action.newGroupId].logs), [action.logId])
        })), _extends4))
      });
    case TOGGLE_NAV_GROUP_OPEN:
    case SET_GROUP_LIST_FILTER:
    case TOGGLE_EDIT_NAME_OPEN:
    case SET_EDITED_NAME:
    case SAVE_GROUP_NAME:
    case SAVE_GROUP_NAME_SUCCESS:
    case _sharedActions.SAVE_GROUP_NAME_FAIL:
    case TOGGLE_DELETE_GROUP_OPEN:
    case DELETE_GROUP:
    case _sharedActions.DELETE_GROUP_FAIL:
    case _sharedActions.GROUP_NAME_CHANGE_EMITTED:
    case _sharedActions.NEW_LOG_EMITTED:
    case _sharedActions.LOG_DELETE_EMITTED:
      return (0, _extends7.default)({}, state, {
        data: (0, _extends7.default)({}, state.data, (0, _defineProperty3.default)({}, action.groupId, groupReducer(state.data[action.groupId], action)))
      });
    default:
      return state;
  }
}

function isLoaded(globalState) {
  return globalState.groups && globalState.groups.loaded;
}

function load() {
  return {
    types: [INITIAL_LOAD, INITIAL_LOAD_SUCCESS, INITIAL_LOAD_FAIL],
    promise: function promise(client) {
      return client.get('/system/getGroups');
    }
  };
}

function toggleNavGroupOpen(groupId) {
  return {
    type: TOGGLE_NAV_GROUP_OPEN,
    groupId: groupId
  };
}

function setGroupListFilter(groupId, newListFilter) {
  return {
    type: SET_GROUP_LIST_FILTER,
    groupId: groupId,
    newListFilter: newListFilter
  };
}

function toggleEditNameOpen(groupId) {
  return {
    type: TOGGLE_EDIT_NAME_OPEN,
    groupId: groupId
  };
}

function setEditedName(groupId, name) {
  return {
    type: SET_EDITED_NAME,
    groupId: groupId,
    name: name
  };
}

function saveGroupName(groupId, newGroupName, groupName) {
  return {
    types: [SAVE_GROUP_NAME, SAVE_GROUP_NAME_SUCCESS, _sharedActions.SAVE_GROUP_NAME_FAIL],
    promise: function promise(client) {
      return client.post('/system/saveGroupName', {
        data: {
          groupId: groupId,
          newGroupName: newGroupName
        }
      });
    },
    groupId: groupId,
    newGroupName: newGroupName,
    groupName: groupName
  };
}

function toggleDeleteGroupOpen(groupId) {
  return {
    type: TOGGLE_DELETE_GROUP_OPEN,
    groupId: groupId
  };
}

function deleteGroup(groupId, groupName) {
  return {
    types: [DELETE_GROUP, DELETE_GROUP_SUCCESS, _sharedActions.DELETE_GROUP_FAIL],
    promise: function promise(client) {
      return client.post('/system/deleteGroup', {
        data: {
          groupId: groupId
        }
      });
    },
    groupId: groupId,
    groupName: groupName
  };
}