'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

exports.default = reducer;
exports.toggleSortByGroup = toggleSortByGroup;
exports.toggleInputingNewGroup = toggleInputingNewGroup;
exports.setNewLogName = setNewLogName;
exports.setNewLogGroup = setNewLogGroup;
exports.setNewLogFile = setNewLogFile;
exports.setNewLogPath = setNewLogPath;
exports.createNewLog = createNewLog;

var _sharedActions = require('./sharedActions.js');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var TOGGLE_SORT_BY_GROUP = 'logger-app/logManagement/TOGGLE_SORT_BY_GROUP';
var TOGGLE_INPUTING_NEW_LOG = 'logger-app/logManagement/TOGGLE_INPUTING_NEW_LOG';
var SET_NEW_LOG_NAME = 'logger-app/logManagement/SET_NEW_LOG_NAME';
var SET_NEW_LOG_GROUP = 'logger-app/logManagement/SET_NEW_LOG_GROUP';
var SET_NEW_LOG_FILE = 'logger-app/logManagement/SET_NEW_LOG_FILE';
var SET_NEW_LOG_PATH = 'logger-app/logManagement/SET_NEW_LOG_PATH';
var CREATE_NEW_LOG = 'logger-app/logManagement/CREATE_NEW_LOG';
var CREATE_NEW_LOG_SUCCESS = 'logger-app/logManagement/CREATE_NEW_LOG_SUCCESS';

var initialState = {
  sortByGroup: true,
  inputingNewLog: false,
  savingNewLog: false,
  errorSavingNewLog: false,
  newLogName: '',
  newLogGroup: '-1',
  newLogFile: '',
  newLogPath: ''
};

function reducer() {
  var state = arguments.length <= 0 || arguments[0] === undefined ? initialState : arguments[0];
  var action = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

  switch (action.type) {
    case TOGGLE_SORT_BY_GROUP:
      return (0, _extends3.default)({}, state, {
        sortByGroup: !state.sortByGroup
      });
    case TOGGLE_INPUTING_NEW_LOG:
      return (0, _extends3.default)({}, state, {
        inputingNewLog: !state.inputingNewLog
      });
    case SET_NEW_LOG_NAME:
      return (0, _extends3.default)({}, state, {
        newLogName: action.newLogName,
        errorSavingNewLog: false
      });
    case SET_NEW_LOG_GROUP:
      return (0, _extends3.default)({}, state, {
        newLogGroup: action.newLogGroup
      });
    case SET_NEW_LOG_FILE:
      return (0, _extends3.default)({}, state, {
        newLogFile: action.newLogFile
      });
    case SET_NEW_LOG_PATH:
      console.log('SET_NEW_LOG_PATH');
      return (0, _extends3.default)({}, state, {
        newLogPath: action.newLogPath
      });
    case CREATE_NEW_LOG:
      return (0, _extends3.default)({}, state, {
        savingNewLog: true
      });
    case CREATE_NEW_LOG_SUCCESS:
      return (0, _extends3.default)({}, state, {
        inputingNewLog: false,
        savingNewLog: false,
        newLogName: '',
        newLogGroup: '-1',
        newLogFile: '',
        newLogPath: ''
      });
    case _sharedActions.CREATE_NEW_LOG_FAIL:
      return (0, _extends3.default)({}, state, {
        savingNewLog: false,
        errorSavingNewLog: true
      });
    default:
      return state;
  }
}

function toggleSortByGroup() {
  return {
    type: TOGGLE_SORT_BY_GROUP
  };
}

function toggleInputingNewGroup() {
  return {
    type: TOGGLE_INPUTING_NEW_LOG
  };
}

function setNewLogName(newLogName) {
  return {
    type: SET_NEW_LOG_NAME,
    newLogName: newLogName
  };
}

function setNewLogGroup(newLogGroup) {
  return {
    type: SET_NEW_LOG_GROUP,
    newLogGroup: newLogGroup
  };
}

function setNewLogFile(newLogFile) {
  return {
    type: SET_NEW_LOG_FILE,
    newLogFile: newLogFile
  };
}

function setNewLogPath(newLogPath) {
  return {
    type: SET_NEW_LOG_PATH,
    newLogPath: newLogPath
  };
}

function createNewLog(logName, groupId, logFile, logPath) {
  return {
    types: [CREATE_NEW_LOG, CREATE_NEW_LOG_SUCCESS, _sharedActions.CREATE_NEW_LOG_FAIL],
    promise: function promise(client) {
      return client.post('/system/createNewLog', {
        data: {
          logName: logName,
          groupId: groupId,
          logFile: logFile,
          logPath: logPath
        }
      });
    }
  };
}