'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _defineProperty2 = require('babel-runtime/helpers/defineProperty');

var _defineProperty3 = _interopRequireDefault(_defineProperty2);

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _extends5 = require('babel-runtime/helpers/extends');

var _extends6 = _interopRequireDefault(_extends5);

exports.default = logs;
exports.isLoaded = isLoaded;
exports.load = load;
exports.activateLog = activateLog;
exports.pauseLog = pauseLog;
exports.resumeLog = resumeLog;
exports.deactivateLog = deactivateLog;
exports.clearLogOutput = clearLogOutput;
exports.toggleScrollLock = toggleScrollLock;
exports.toggleLogExtraActionsOpen = toggleLogExtraActionsOpen;
exports.addLineToLog = addLineToLog;
exports.setLogRead = setLogRead;
exports.toggleEditOpen = toggleEditOpen;
exports.setEditedName = setEditedName;
exports.setEditedGroup = setEditedGroup;
exports.setEditedPath = setEditedPath;
exports.setEditedFile = setEditedFile;
exports.saveLogChanges = saveLogChanges;
exports.toggleDeleteLogOpen = toggleDeleteLogOpen;
exports.deleteLog = deleteLog;

var _sharedActions = require('./sharedActions.js');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var INITIAL_LOAD = 'logger-app/logs/INITIAL_LOAD';
var INITIAL_LOAD_SUCCESS = 'logger-app/logs/INITIAL_LOAD_SUCCESS';
var INITIAL_LOAD_FAIL = 'logger-app/logs/INITIAL_LOAD_FAIL';

var ACTIVATE_LOG = 'logger-app/logs/ACTIVATE_LOG';
var PAUSE_LOG = 'logger-app/logs/PAUSE_LOG';
var RESUME_LOG = 'logger-app/logs/RESUME_LOG';
var DEACTIVATE_LOG = 'logger-app/logs/DEACTIVATE_LOG';
var CLEAR_LOG_OUTPUT = 'logger-app/logs/CLEAR_LOG_OUTPUT';
var TOGGLE_SCROLL_LOCK = 'logger-app/logs/TOGGLE_SCROLL_LOCK';
var TOGGLE_LOG_EXTRA_ACTIONS_OPEN = 'logger-app/logs/TOGGLE_LOG_EXTRA_ACTIONS_OPEN';

var ADD_LINE_TO_LOG = 'logger-app/logs/ADD_LINE_TO_LOG';
var SET_LOG_READ = 'logger-app/logs/SET_LOG_READ';

// Log Management actions
// Edit Group Name
var TOGGLE_EDIT_OPEN = 'logger-app/logs/TOGGLE_EDIT_OPEN';
var SET_EDITED_NAME = 'logger-app/logs/SET_EDITED_NAME';
var SET_EDITED_GROUP = 'logger-app/logs/SET_EDITED_GROUP';
var SET_EDITED_FILE = 'logger-app/logs/SET_EDITED_FILE';
var SET_EDITED_PATH = 'logger-app/logs/SET_EDITED_PATH';
var SAVE_LOG_CHANGES = 'logger-app/logs/SAVE_LOG_CHANGES';
var SAVE_LOG_CHANGES_SUCCESS = 'logger-app/logs/SAVE_LOG_CHANGES_SUCCESS';

// Delete Group
var TOGGLE_DELETE_LOG_OPEN = 'logger-app/logs/TOGGLE_DELETE_LOG_OPEN';
var DELETE_LOG = 'logger-app/logs/DELETE_LOG';
var DELETE_LOG_SUCCESS = 'logger-app/logs/DELETE_LOG_SUCCESS';

// Socket Events

var initialState = {
  loaded: false
};

var applyDefaultLogValues = function applyDefaultLogValues(log) {
  return (0, _extends6.default)({}, log, {
    logData: [],
    pausedLogData: [],
    extraActionsOpen: false,
    activeState: 'INACTIVE',
    hasNew: false,
    scrollLocked: true,
    logLevelMapping: null,
    tailError: null,
    // Log Management Page Variables
    editPanelOpen: false,
    editedName: log.name,
    editedGroup: null,
    editedFile: log.fname,
    editedPath: log.fpath,
    editSaving: false,
    deletePanelOpen: false,
    deleteSaving: false
  });
};

var logReducer = function logReducer(state, action) {
  switch (action.type) {
    case ACTIVATE_LOG:
      return (0, _extends6.default)({}, state, {
        activeState: 'ACTIVE',
        tailError: null
      });
    case PAUSE_LOG:
      return (0, _extends6.default)({}, state, {
        activeState: 'PAUSED'
      });
    case RESUME_LOG:
      return (0, _extends6.default)({}, state, {
        activeState: 'ACTIVE',
        logData: state.logData.concat(state.pausedLogData),
        pausedLogData: []
      });
    case DEACTIVATE_LOG:
      return (0, _extends6.default)({}, state, {
        activeState: state.logData.length ? 'INACTIVE_WITH_OUTPUT' : 'INACTIVE',
        pausedLogData: []
      });
    case CLEAR_LOG_OUTPUT:
      return (0, _extends6.default)({}, state, {
        activeState: state.activeState === 'INACTIVE_WITH_OUTPUT' ? 'INACTIVE' : state.activeState,
        logData: [],
        pausedLogData: []
      });
    case TOGGLE_SCROLL_LOCK:
      return (0, _extends6.default)({}, state, {
        scrollLocked: !state.scrollLocked
      });
    case TOGGLE_LOG_EXTRA_ACTIONS_OPEN:
      return (0, _extends6.default)({}, state, {
        extraActionsOpen: !state.extraActionsOpen
      });
    case ADD_LINE_TO_LOG:
      return (0, _extends6.default)({}, state, {
        logData: state.activeState === 'PAUSED' ? state.logData : state.logData.concat(action.newLine),
        pausedLogData: state.activeState === 'PAUSED' ? state.pausedLogData.concat(action.newLine) : state.pausedLogData,
        hasNew: true
      });
    case SET_LOG_READ:
      return (0, _extends6.default)({}, state, {
        hasNew: false
      });
    case _sharedActions.TAIL_ERROR_EMITTED:
      return (0, _extends6.default)({}, state, {
        activeState: 'INACTIVE'
      });
    case TOGGLE_EDIT_OPEN:
      return (0, _extends6.default)({}, state, {
        editPanelOpen: !state.editPanelOpen
      });
    case SET_EDITED_NAME:
      return (0, _extends6.default)({}, state, {
        editedName: action.editedName
      });
    case SET_EDITED_GROUP:
      return (0, _extends6.default)({}, state, {
        editedGroup: action.editedGroup
      });
    case SET_EDITED_FILE:
      return (0, _extends6.default)({}, state, {
        editedFile: action.editedFile
      });
    case SET_EDITED_PATH:
      return (0, _extends6.default)({}, state, {
        editedPath: action.editedPath
      });
    case SAVE_LOG_CHANGES:
      return (0, _extends6.default)({}, state, {
        editSaving: true
      });
    case SAVE_LOG_CHANGES_SUCCESS:
      return (0, _extends6.default)({}, state, {
        editPanelOpen: false,
        editSaving: false
      });
    case _sharedActions.SAVE_LOG_CHANGES_FAIL:
      return (0, _extends6.default)({}, state, {
        editSaving: false
      });
    case TOGGLE_DELETE_LOG_OPEN:
      return (0, _extends6.default)({}, state, {
        deletePanelOpen: !state.deletePanelOpen
      });
    case DELETE_LOG:
      return (0, _extends6.default)({}, state, {
        deleteSaving: true
      });
    case _sharedActions.DELETE_LOG_FAIL:
      return (0, _extends6.default)({}, state, {
        deleteSaving: false
      });
    case _sharedActions.LOG_NAME_CHANGE_EMITTED:
      return (0, _extends6.default)({}, state, {
        name: action.newName
      });
    case _sharedActions.LOG_FILE_CHANGE_EMITTED:
      return (0, _extends6.default)({}, state, {
        fname: action.newFile
      });
    case _sharedActions.LOG_PATH_CHANGE_EMITTED:
      return (0, _extends6.default)({}, state, {
        fpath: action.newPath
      });
    default:
      return state;
  }
};

function logs() {
  var state = arguments.length <= 0 || arguments[0] === undefined ? initialState : arguments[0];
  var action = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

  switch (action.type) {
    case INITIAL_LOAD:
      return (0, _extends6.default)({}, state, {
        loading: true
      });
    case INITIAL_LOAD_SUCCESS:
      return (0, _extends6.default)({}, state, {
        loading: false,
        loaded: true,
        data: (0, _keys2.default)(action.result).reduce(function (prev, logId) {
          return (0, _extends6.default)({}, prev, (0, _defineProperty3.default)({}, logId, applyDefaultLogValues(action.result[logId])));
        }, {}),
        error: null
      });
    case INITIAL_LOAD_FAIL:
      return (0, _extends6.default)({}, state, {
        loading: false,
        loaded: false,
        data: null,
        error: action.error
      });
    case _sharedActions.NEW_LOG_EMITTED:
      return (0, _extends6.default)({}, state, {
        data: (0, _extends6.default)({}, state.data, (0, _defineProperty3.default)({}, action.newLogId, applyDefaultLogValues({
          name: action.logName,
          fname: action.logFile,
          fpath: action.logPath
        })))
      });
    case _sharedActions.LOG_DELETE_EMITTED:
      var _state$data = state.data;
      var omit = _state$data[action.logId];
      var others = (0, _objectWithoutProperties3.default)(_state$data, [action.logId]);

      return (0, _extends6.default)({}, state, {
        data: others
      });
    case _sharedActions.GROUP_DELETE_EMITTED:
      var savedLogs = (0, _objectWithoutProperties3.default)(state.data, []);

      action.logIds.forEach(function (logId) {
        var _savedLogs = savedLogs;
        var omitLog = _savedLogs[logId];
        var nextSavedLogs = (0, _objectWithoutProperties3.default)(_savedLogs, [logId]);

        savedLogs = nextSavedLogs;
      });
      return (0, _extends6.default)({}, state, {
        data: savedLogs
      });
    case ACTIVATE_LOG:
    case PAUSE_LOG:
    case RESUME_LOG:
    case DEACTIVATE_LOG:
    case CLEAR_LOG_OUTPUT:
    case TOGGLE_SCROLL_LOCK:
    case TOGGLE_LOG_EXTRA_ACTIONS_OPEN:
    case ADD_LINE_TO_LOG:
    case SET_LOG_READ:
    case _sharedActions.TAIL_ERROR_EMITTED:
    case TOGGLE_EDIT_OPEN:
    case SET_EDITED_NAME:
    case SET_EDITED_GROUP:
    case SET_EDITED_FILE:
    case SET_EDITED_PATH:
    case SAVE_LOG_CHANGES:
    case SAVE_LOG_CHANGES_SUCCESS:
    case _sharedActions.SAVE_LOG_CHANGES_FAIL:
    case TOGGLE_DELETE_LOG_OPEN:
    case DELETE_LOG:
    case _sharedActions.DELETE_LOG_FAIL:
    case _sharedActions.LOG_NAME_CHANGE_EMITTED:
    case _sharedActions.LOG_FILE_CHANGE_EMITTED:
    case _sharedActions.LOG_PATH_CHANGE_EMITTED:
      return (0, _extends6.default)({}, state, {
        data: (0, _extends6.default)({}, state.data, (0, _defineProperty3.default)({}, action.logId, logReducer(state.data[action.logId], action)))
      });
    default:
      return state;
  }
}

function isLoaded(globalState) {
  return globalState.logs && globalState.logs.loaded;
}

function load() {
  return {
    types: [INITIAL_LOAD, INITIAL_LOAD_SUCCESS, INITIAL_LOAD_FAIL],
    promise: function promise(client) {
      return client.get('/system/getLogs');
    }
  };
}

function activateLog(logId) {
  return {
    type: ACTIVATE_LOG,
    logId: logId
  };
}

function pauseLog(logId) {
  return {
    type: PAUSE_LOG,
    logId: logId
  };
}

function resumeLog(logId) {
  return {
    type: RESUME_LOG,
    logId: logId
  };
}

function deactivateLog(logId) {
  return {
    type: DEACTIVATE_LOG,
    logId: logId
  };
}

function clearLogOutput(logId) {
  return {
    type: CLEAR_LOG_OUTPUT,
    logId: logId
  };
}

function toggleScrollLock(logId) {
  return {
    type: TOGGLE_SCROLL_LOCK,
    logId: logId
  };
}

function toggleLogExtraActionsOpen(logId) {
  return {
    type: TOGGLE_LOG_EXTRA_ACTIONS_OPEN,
    logId: logId
  };
}

function addLineToLog(logId, newLine) {
  return {
    type: ADD_LINE_TO_LOG,
    logId: logId,
    newLine: newLine
  };
}

function setLogRead(logId) {
  return {
    type: SET_LOG_READ,
    logId: logId
  };
}

function toggleEditOpen(logId) {
  return {
    type: TOGGLE_EDIT_OPEN,
    logId: logId
  };
}

function setEditedName(logId, editedName) {
  return {
    type: SET_EDITED_NAME,
    logId: logId,
    editedName: editedName
  };
}

function setEditedGroup(logId, editedGroup) {
  return {
    type: SET_EDITED_GROUP,
    logId: logId,
    editedGroup: editedGroup
  };
}

function setEditedPath(logId, editedPath) {
  return {
    type: SET_EDITED_PATH,
    logId: logId,
    editedPath: editedPath
  };
}

function setEditedFile(logId, editedFile) {
  return {
    type: SET_EDITED_FILE,
    logId: logId,
    editedFile: editedFile
  };
}

function saveLogChanges(logId, logName, oldGroupId, editedName, editedGroupId, editedFile, editedPath) {
  return {
    types: [SAVE_LOG_CHANGES, SAVE_LOG_CHANGES_SUCCESS, _sharedActions.SAVE_LOG_CHANGES_FAIL],
    promise: function promise(client) {
      return client.post('/system/saveLogChanges', {
        data: {
          logId: logId,
          oldGroupId: oldGroupId,
          editedName: editedName,
          editedGroupId: editedGroupId,
          editedFile: editedFile,
          editedPath: editedPath
        }
      });
    },
    logId: logId,
    logName: logName
  };
}

function toggleDeleteLogOpen(logId) {
  return {
    type: TOGGLE_DELETE_LOG_OPEN,
    logId: logId
  };
}

function deleteLog(groupId, logId, logName) {
  return {
    types: [DELETE_LOG, DELETE_LOG_SUCCESS, _sharedActions.DELETE_LOG_FAIL],
    promise: function promise(client) {
      return client.post('/system/deleteLog', {
        data: {
          groupId: groupId,
          logId: logId
        }
      });
    },
    logId: logId,
    logName: logName
  };
}