'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

exports.default = notifications;
exports.clearNotification = clearNotification;

var _sharedActions = require('./sharedActions.js');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var CLEAR_NOTIFICATION = 'logger-app/notifications/CLEAR_NOTIFICATION';

var initialState = {
  nextId: 0,
  list: []
};

function notifications() {
  var state = arguments.length <= 0 || arguments[0] === undefined ? initialState : arguments[0];
  var action = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

  switch (action.type) {
    case CLEAR_NOTIFICATION:
      return (0, _extends3.default)({}, state, {
        list: [].concat((0, _toConsumableArray3.default)(state.list.slice(0, action.position)), (0, _toConsumableArray3.default)(state.list.slice(action.position + 1)))
      });
    case _sharedActions.NEW_GROUP_EMITTED:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'INFO',
          'message': 'New group "' + action.newGroupName + '" has been created'
        }])
      };
    case _sharedActions.GROUP_NAME_CHANGE_EMITTED:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'INFO',
          'message': 'Group "' + action.oldName + '" has been renamed "' + action.newName + '"'
        }])
      };
    case _sharedActions.GROUP_DELETE_EMITTED:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'INFO',
          'message': 'Group "' + action.groupName + '" has been deleted'
        }])
      };
    case _sharedActions.NEW_LOG_EMITTED:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'INFO',
          'message': 'New log "' + action.logName + '" created in group "' + action.groupName + '"'
        }])
      };
    case _sharedActions.LOG_DELETE_EMITTED:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'INFO',
          'message': 'Log "' + action.logName + '" has been deleted from group "' + action.groupName + '"'
        }])
      };
    case _sharedActions.TAIL_ERROR_EMITTED:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'ERROR',
          'message': action.errorReason + ' (' + action.errorCode + ')'
        }])
      };
    case _sharedActions.CREATE_NEW_GROUP_FAIL:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'ERROR',
          'message': 'Failed to create new group". ' + action.error.errorReason
        }])
      };
    case _sharedActions.SAVE_GROUP_NAME_FAIL:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'ERROR',
          'message': 'Failed to save new group name "' + action.newGroupName + '" for group "' + action.groupName + '". ' + action.error.errorReason
        }])
      };
    case _sharedActions.DELETE_GROUP_FAIL:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'ERROR',
          'message': 'Failed to delete group "' + action.groupName + '". ' + action.error.errorReason
        }])
      };
    case _sharedActions.CREATE_NEW_LOG_FAIL:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'ERROR',
          'message': 'Failed to create new log. ' + action.error.errorReason
        }])
      };
    case _sharedActions.LOG_NAME_CHANGE_EMITTED:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'INFO',
          'message': 'Log "' + action.oldName + '" has been renamed "' + action.newName + '"'
        }])
      };
    case _sharedActions.LOG_GROUP_CHANGE_EMITTED:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'INFO',
          'message': 'Log "' + action.logName + '" has been moved from group "' + action.oldGroupName + '" to "' + action.newGroupName + '"'
        }])
      };
    case _sharedActions.LOG_FILE_CHANGE_EMITTED:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'INFO',
          'message': 'Log file for "' + action.logName + '" has changed from "' + action.oldFile + '" to "' + action.newFile + '"'
        }])
      };
    case _sharedActions.LOG_PATH_CHANGE_EMITTED:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'INFO',
          'message': 'Log path for "' + action.logName + '" has changed from "' + action.oldPath + '" to "' + action.newPath + '"'
        }])
      };
    case _sharedActions.SAVE_LOG_CHANGES_FAIL:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'ERROR',
          'message': 'Failed to edit log "' + action.logName + '". ' + action.error.errorReason
        }])
      };
    case _sharedActions.DELETE_LOG_FAIL:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'ERROR',
          'message': 'Failed to delete log "' + action.logName + '". ' + action.error.errorReason
        }])
      };
    case _sharedActions.APP_MANAGMENT_SAVE_SUCCESS:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'INFO',
          'message': 'App settings changes saved successfully. Restart the app for any port changes to take effect.'
        }])
      };
    case _sharedActions.APP_MANAGMENT_SAVE_FAIL:
      return {
        nextId: state.nextId + 1,
        list: [].concat((0, _toConsumableArray3.default)(state.list), [{
          id: state.nextId,
          type: 'ERROR',
          'message': 'Failed to save app settings changes. ' + action.error.errorReason
        }])
      };
    default:
      return state;
  }
}

function clearNotification(position) {
  return {
    type: CLEAR_NOTIFICATION,
    position: position
  };
}