'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactRouter = require('react-router');

var _auth = require('./redux/modules/auth');

var _containers = require('./containers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = function (store) {
  var requireLoggedInOrNoAuth = function requireLoggedInOrNoAuth(nextState, replaceState, cb) {
    function checkAuth() {
      var _store$getState = store.getState();

      var _store$getState$auth = _store$getState.auth;
      var enabled = _store$getState$auth.enabled;
      var user = _store$getState$auth.user;

      if (enabled && !user) {
        // oops, not logged in, so can't be here!
        replaceState(null, '/login');
      }
      cb();
    }

    if (!(0, _auth.isLoaded)(store.getState())) {
      store.dispatch((0, _auth.load)()).then(checkAuth);
    } else {
      checkAuth();
    }
  };

  var requireLoggedOutAndAuth = function requireLoggedOutAndAuth(nextState, replaceState, cb) {
    function checkAuth() {
      var _store$getState2 = store.getState();

      var _store$getState2$auth = _store$getState2.auth;
      var enabled = _store$getState2$auth.enabled;
      var user = _store$getState2$auth.user;

      if (!enabled || !!user) {
        replaceState(null, '/dashboard');
      }
      cb();
    }

    if (!(0, _auth.isLoaded)(store.getState())) {
      store.dispatch((0, _auth.load)()).then(checkAuth);
    } else {
      checkAuth();
    }
  };

  /**
   * Please keep routes in alphabetical order
   */
  return _react2.default.createElement(
    _reactRouter.Route,
    { path: '/', component: _containers.App },
    _react2.default.createElement(_reactRouter.IndexRedirect, { to: 'dashboard' }),
    _react2.default.createElement(
      _reactRouter.Route,
      { onEnter: requireLoggedOutAndAuth },
      _react2.default.createElement(_reactRouter.Route, { path: 'login', component: _containers.Login })
    ),
    _react2.default.createElement(
      _reactRouter.Route,
      { path: 'dashboard', component: _containers.Dashboard, onEnter: requireLoggedInOrNoAuth },
      _react2.default.createElement(_reactRouter.IndexRoute, { component: _containers.DashboardHome }),
      _react2.default.createElement(_reactRouter.Route, { path: 'active', component: _containers.ActiveGroup }),
      _react2.default.createElement(_reactRouter.Route, { path: 'group/:groupId', component: _containers.Group }),
      _react2.default.createElement(
        _reactRouter.Route,
        { path: 'log/:logId', component: _containers.Log },
        _react2.default.createElement(_reactRouter.IndexRoute, { component: _containers.LogOutput }),
        _react2.default.createElement(_reactRouter.Route, { path: 'output', component: _containers.LogOutput }),
        _react2.default.createElement(_reactRouter.Route, { path: 'analysis', component: _containers.Analysis })
      ),
      _react2.default.createElement(
        _reactRouter.Route,
        { path: 'settings', component: _containers.Admin },
        _react2.default.createElement(_reactRouter.IndexRedirect, { to: 'groups' }),
        _react2.default.createElement(_reactRouter.Route, { path: 'app', component: _containers.AppManagement }),
        _react2.default.createElement(_reactRouter.Route, { path: 'groups', component: _containers.GroupManagement }),
        _react2.default.createElement(_reactRouter.Route, { path: 'logs', component: _containers.LogManagement }),
        _react2.default.createElement(_reactRouter.Route, { path: 'users', component: _containers.GroupManagement }),
        _react2.default.createElement(_reactRouter.Route, { path: 'syntax', component: _containers.GroupManagement })
      )
    ),
    _react2.default.createElement(_reactRouter.Route, { path: '*', component: _containers.NotFound, status: 404 })
  );
};

module.exports = exports['default'];