'use strict';

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _express = require('express');

var _express2 = _interopRequireDefault(_express);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _server = require('react-dom/server');

var _server2 = _interopRequireDefault(_server);

var _config = require('./config');

var _config2 = _interopRequireDefault(_config);

var _serveFavicon = require('serve-favicon');

var _serveFavicon2 = _interopRequireDefault(_serveFavicon);

var _compression = require('compression');

var _compression2 = _interopRequireDefault(_compression);

var _httpProxy = require('http-proxy');

var _httpProxy2 = _interopRequireDefault(_httpProxy);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _create = require('./redux/create');

var _create2 = _interopRequireDefault(_create);

var _ApiClient = require('./helpers/ApiClient');

var _ApiClient2 = _interopRequireDefault(_ApiClient);

var _Html = require('./helpers/Html');

var _Html2 = _interopRequireDefault(_Html);

var _prettyError = require('pretty-error');

var _prettyError2 = _interopRequireDefault(_prettyError);

var _http = require('http');

var _http2 = _interopRequireDefault(_http);

var _reduxRouter = require('redux-router');

var _createMemoryHistory = require('history/lib/createMemoryHistory');

var _createMemoryHistory2 = _interopRequireDefault(_createMemoryHistory);

var _server3 = require('redux-router/server');

var _reactRedux = require('react-redux');

var _queryString = require('query-string');

var _queryString2 = _interopRequireDefault(_queryString);

var _routes = require('./routes');

var _routes2 = _interopRequireDefault(_routes);

var _getStatusFromRoutes = require('./helpers/getStatusFromRoutes');

var _getStatusFromRoutes2 = _interopRequireDefault(_getStatusFromRoutes);

var _loggingManager = require('logging-manager');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var targetUrl = 'http://' + _config2.default.apiHost + ':' + _config2.default.apiPort;
var pretty = new _prettyError2.default();
var app = new _express2.default();
var server = new _http2.default.Server(app);
var proxy = _httpProxy2.default.createProxyServer({
  target: targetUrl,
  ws: true
});

var relativeStaticLocation = global.__LIB_VERSION__ ? '../..' : '..';

app.use((0, _compression2.default)());
app.use((0, _serveFavicon2.default)(_path2.default.join(__dirname, relativeStaticLocation, 'static', 'favicon.ico')));

app.use(_express2.default.static(_path2.default.join(__dirname, relativeStaticLocation, 'static')));

// Proxy to API server
app.use('/api', function (req, res) {
  proxy.web(req, res, { target: targetUrl });
});

app.use('/ws', function (req, res) {
  proxy.web(req, res, { target: targetUrl + '/ws' });
});

server.on('upgrade', function (req, socket, head) {
  proxy.ws(req, socket, head);
});

// added the error handling to avoid https://github.com/nodejitsu/node-http-proxy/issues/527
proxy.on('error', function (error, req, res) {
  var json = undefined;
  if (error.code !== 'ECONNRESET') {
    _loggingManager.Instance.error('WEB', 'main', 'API proxy error');
    _loggingManager.Instance.error('WEB', 'main', error);
  }
  if (!res.headersSent) {
    res.writeHead(500, { 'content-type': 'application/json' });
  }

  json = { error: 'proxy_error', reason: error.message };
  res.end((0, _stringify2.default)(json));
});

app.use(function (req, res) {
  if (__DEVELOPMENT__) {
    // Do not cache webpack stats: the script file would change since
    // hot module replacement is enabled in the development env
    webpackIsomorphicTools.refresh();
  }
  var client = new _ApiClient2.default(req);

  var store = (0, _create2.default)(_server3.reduxReactRouter, _routes2.default, _createMemoryHistory2.default, client);

  function hydrateOnClient() {
    res.send('<!doctype html>\n' + _server2.default.renderToString(_react2.default.createElement(_Html2.default, { assets: webpackIsomorphicTools.assets(), store: store })));
  }

  if (__DISABLE_SSR__) {
    hydrateOnClient();
    return;
  }

  store.dispatch((0, _server3.match)(req.originalUrl, function (error, redirectLocation, routerState) {
    if (redirectLocation) {
      res.redirect(redirectLocation.pathname + redirectLocation.search);
    } else if (error) {
      _loggingManager.Instance.error('WEB', 'main', 'Router error:');
      _loggingManager.Instance.error('WEB', 'main', pretty.render(error));
      res.status(500);
      hydrateOnClient();
    } else if (!routerState) {
      res.status(500);
      hydrateOnClient();
    } else {
      // Workaround redux-router query string issue:
      // https://github.com/rackt/redux-router/issues/106
      if (routerState.location.search && !routerState.location.query) {
        routerState.location.query = _queryString2.default.parse(routerState.location.search);
      }

      store.getState().router.then(function () {
        var component = _react2.default.createElement(
          _reactRedux.Provider,
          { store: store, key: 'provider' },
          _react2.default.createElement(_reduxRouter.ReduxRouter, null)
        );

        var status = (0, _getStatusFromRoutes2.default)(routerState.routes);
        if (status) {
          res.status(status);
        }
        res.send('<!doctype html>\n' + _server2.default.renderToString(_react2.default.createElement(_Html2.default, { assets: webpackIsomorphicTools.assets(), component: component, store: store })));
      }).catch(function (err) {
        _loggingManager.Instance.error('WEB', 'main', 'Data fetching error:');
        _loggingManager.Instance.error('WEB', 'main', pretty.render(err));
        res.status(500);
        hydrateOnClient();
      });
    }
  }));
});

if (_config2.default.port) {
  server.listen(_config2.default.port, function (err) {
    if (err) {
      _loggingManager.Instance.fatal('WEB', 'main', 'Error starting webserver.');
      _loggingManager.Instance.fatal('WEB', 'main', err);
      process.exit(1);
    }
    _loggingManager.Instance.system('WEB', 'main', _config2.default.app.title + ' is running, talking to API server on  port ' + _config2.default.apiPort);
    _loggingManager.Instance.system('WEB', 'main', 'Open http://' + _config2.default.host + ':' + _config2.default.port + ' in a browser to view the app.');
  });
} else {
  _loggingManager.Instance.fatal('WEB', 'main', 'No PORT environment variable has been specified');
  process.exit(1);
}